@@ -25,23 +25,43 @@ namespace siena
  * @param[in] squared indicates if the covariate values must be squared
  */
 SameCovariateActivityEffect::SameCovariateActivityEffect(
-		const EffectInfo * pEffectInfo, bool same) :
+		const EffectInfo * pEffectInfo, bool same, bool recip) :
 	CovariateDependentNetworkEffect(pEffectInfo)
 {
 	this->lsame = same;
+	this->lrecip = recip;
 }
 
 
+/**
+ * Determines the condition combining everything
+ */
+
+bool SameCovariateActivityEffect::lcondition1(int theAlter, double theOwnValue) const
+{
+	return ((fabs(this->value(theAlter) - theOwnValue) < EPSILON) &&
+			(!lrecip | (this->inTieExists(theAlter))));
+}
+
+
+bool SameCovariateActivityEffect::lcondition2(int theAlter, double theOwnValue) const
+{
+	return ((fabs(this->value(theAlter) - theOwnValue) >= EPSILON) &&
+			(!lrecip | (this->inTieExists(theAlter))));
+}
+
 /**
  * Calculates the contribution of a tie flip to the given actor.
  */
+// For recip this is not very efficient, because each alter has the same contribution;
+// could be made more efficient by preprocessEgo?
 double SameCovariateActivityEffect::calculateContribution(int alter) const
 {
 	double myvalue = this->value(this->ego());
 	double contribution = 0;
 	const Network * pNetwork = this->pNetwork();
 
-	if ((lsame) && (fabs(this->value(alter) - myvalue) < EPSILON))
+	if ((lsame) && (lrecip | (fabs(this->value(alter) - myvalue) < EPSILON)))	// fabs(this->value(alter) - myvalue) < EPSILON))
 	{
 		for (IncidentTieIterator iter = pNetwork->outTies(this->ego());
 			iter.valid();
@@ -49,7 +69,7 @@ double SameCovariateActivityEffect::calculateContribution(int alter) const
 		{
 			// Get the receiver of the outgoing tie.
 			int h = iter.actor();
-			if (fabs(this->value(h) - myvalue) < EPSILON)
+			if (lcondition1(h, myvalue)) // (fabs(this->value(h) - myvalue) < EPSILON)
 			{
 				contribution++;
 			}
@@ -62,7 +82,7 @@ double SameCovariateActivityEffect::calculateContribution(int alter) const
 		contribution++;
 	}
 
-	if ((!lsame) && (fabs(this->value(alter) - myvalue) >= EPSILON))
+	if ((!lsame) && (lrecip | (fabs(this->value(alter) - myvalue) >= EPSILON)))  //  fabs(this->value(alter) - myvalue) >= EPSILON))
 	{
 		for (IncidentTieIterator iter = pNetwork->outTies(this->ego());
 			iter.valid();
@@ -70,7 +90,7 @@ double SameCovariateActivityEffect::calculateContribution(int alter) const
 		{
 			// Get the receiver of the outgoing tie.
 			int h = iter.actor();
-			if (fabs(this->value(h) - myvalue) >= EPSILON)
+			if (lcondition2(h, myvalue)) // (fabs(this->value(h) - myvalue) >= EPSILON)
 			{
 				contribution++;
 			}
@@ -103,7 +123,7 @@ double SameCovariateActivityEffect::tieStatistic(int alter)
 
 		if (lsame)
 		{
-			if (fabs(this->value(alter) - myvalue) < EPSILON)
+			if (lrecip | (fabs(this->value(alter) - myvalue) < EPSILON))
 			{
 				for (IncidentTieIterator iter = pNetwork->outTies(this->ego());
 					iter.valid();
@@ -112,7 +132,7 @@ double SameCovariateActivityEffect::tieStatistic(int alter)
 					// Get the receiver of the outgoing tie.
 					int h = iter.actor();
 					if ((!this->missing(h)) &&
-							(fabs(this->value(h) - myvalue) < EPSILON))
+							(lcondition1(h, myvalue))) // (fabs(this->value(h) - myvalue) < EPSILON))
 					{
 						contribution++;
 					}
@@ -121,7 +141,7 @@ double SameCovariateActivityEffect::tieStatistic(int alter)
 		}
 		else
 		{
-			if (fabs(this->value(alter) - myvalue) >= EPSILON)
+			if (lrecip | (fabs(this->value(alter) - myvalue) >= EPSILON))
 			{
 				for (IncidentTieIterator iter = pNetwork->outTies(this->ego());
 					iter.valid();
@@ -130,7 +150,8 @@ double SameCovariateActivityEffect::tieStatistic(int alter)
 					// Get the receiver of the outgoing tie.
 					int h = iter.actor();
 					if ((!this->missing(h)) &&
-							(fabs(this->value(h) - myvalue) >= EPSILON))
+							(lcondition2(h, myvalue)))
+							//(fabs(this->value(h) - myvalue) >= EPSILON))
 					{
 						contribution++;
 					}
